summaryrefslogtreecommitdiffstats
path: root/chrome/renderer
diff options
context:
space:
mode:
authorlzheng@google.com <lzheng@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-28 06:48:21 +0000
committerlzheng@google.com <lzheng@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-28 06:48:21 +0000
commit115f5540fcfb3e33e74e5ad7c4793aebd5513a9e (patch)
tree38eff84814b8c5ce081b07b54f4dfd512ab82162 /chrome/renderer
parent6bef62500d72324cc06201adf4d7058555e57371 (diff)
downloadchromium_src-115f5540fcfb3e33e74e5ad7c4793aebd5513a9e.zip
chromium_src-115f5540fcfb3e33e74e5ad7c4793aebd5513a9e.tar.gz
chromium_src-115f5540fcfb3e33e74e5ad7c4793aebd5513a9e.tar.bz2
Make sure we check http/https to collect stats for spdy or apa.
SpdyTrial_npn_http/npn_spdy: compare them for https traffic. xxx_AlternateProtocol_spdy/http: compare them for http traffic. BUG=46689 TEST=none Review URL: http://codereview.chromium.org/3023022 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@53916 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/renderer')
-rw-r--r--chrome/renderer/render_view.cc22
1 files changed, 10 insertions, 12 deletions
diff --git a/chrome/renderer/render_view.cc b/chrome/renderer/render_view.cc
index 820ce97c..efd68b3 100644
--- a/chrome/renderer/render_view.cc
+++ b/chrome/renderer/render_view.cc
@@ -4737,17 +4737,16 @@ void RenderView::DumpLoadHistograms() const {
"PLT.BeginToFinishDoc_LinkLoad", "CacheSize"), begin_to_finish_doc);
}
- // Histograms to determine if SPDY has an impact.
+
+ GURL url = GURL(main_frame->url());
+
+ // Histograms to determine if SPDY has an impact for https traffic.
// TODO(mbelshe): After we've seen the difference between BeginToFinish
// and StartToFinish, consider removing one or the other.
static bool use_spdy_histogram(FieldTrialList::Find("SpdyImpact") &&
!FieldTrialList::Find("SpdyImpact")->group_name().empty());
- // Spdy requests triggered by alternate protocol are excluded here.
- // This is because when alternate protocol is avaiable, FieldTrial will
- // either use npn_spdy or pure http, not npn_http via TLS. That will cause
- // bias for npn_spdy and npn_http.
- if (use_spdy_histogram && navigation_state->was_npn_negotiated() &&
- !navigation_state->was_alternate_protocol_available()) {
+ if (use_spdy_histogram && url.SchemeIs("https") &&
+ navigation_state->was_npn_negotiated()) {
UMA_HISTOGRAM_ENUMERATION(
FieldTrial::MakeName("PLT.Abandoned", "SpdyImpact"),
abandoned_page ? 1 : 0, 2);
@@ -4779,9 +4778,10 @@ void RenderView::DumpLoadHistograms() const {
}
}
- // Histograms to compare the impact of alternate protocol: when the
- // protocol(spdy) is used vs. when it is ignored and http is used.
- if (navigation_state->was_alternate_protocol_available()) {
+ // Histograms to compare the impact of alternate protocol over http traffic:
+ // when spdy is used vs. when http is used.
+ if (url.SchemeIs("http") &&
+ navigation_state->was_alternate_protocol_available()) {
if (!navigation_state->was_npn_negotiated()) {
// This means that even there is alternate protocols for npn_http or
// npn_spdy, they are not taken (due to the fieldtrial).
@@ -4830,7 +4830,6 @@ void RenderView::DumpLoadHistograms() const {
}
// Record page load time and abandonment rates for proxy cases.
- GURL url = GURL(main_frame->url());
if (navigation_state->was_fetched_via_proxy()) {
if (url.SchemeIs("https")) {
PLT_HISTOGRAM("PLT.StartToFinish.Proxy.https", start_to_finish);
@@ -5209,4 +5208,3 @@ bool RenderView::IsNonLocalTopLevelNavigation(
}
return false;
}
-